##  General Guidelines
Here is a summary of some best practices, which are explained below in more detail:
  1. Think backward: Before modeling something, ask yourself these questions: What are we trying to achieve? Which insights from reports and views do we want to create? This will give you guidance on what you need.
**Tip**
Especially for larger teams and organizations, it can be beneficial to document and communicate these decisions to get consistent modeling for similar entities. For example, the modeling of your ERP platform should be agreed on and understood by everyone in your team. This way, you get a global view of your EA landscape.
  2. Use elements wisely: Each element you add beyond the default settings will add more data and require more maintenance. Explore and use what is already in the default settings before adding a new fact sheet subtypes, tag, custom fields, or hierarchy in.
  3. Follow established standards: The more SAP LeanIX standards you apply, the more you and your organization can rely on SAP LeanIX documentation and resources – removing the heavy lifting for your team to create separate documentation.
  4. Document all changes: If you make changes or add new elements, ensure that all of that is documented and understood by your team and other relevant stakeholders using SAP LeanIX.
